package com.hgwebservice.config;

import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;

import java.util.Arrays;

@Getter
@AllArgsConstructor
@NoArgsConstructor
public enum PeriodMarkEnum {

//    P_M_6_0("6_0", "晨起"),
    P_M_1_2("1_2", "早餐前"),
    P_M_1_1("1_1", "早餐后2h"),
    P_M_2_2("2_2", "午餐前"),
    P_M_2_1("2_1", "午餐后2h"),
    P_M_3_2("3_2", "晚餐前"),
    P_M_3_1("3_1", "晚餐后2h"),
    P_M_0_0("0_0", "睡前"),
    P_M_5_0("5_0", "00:00"),
    P_M_7_0("7_0", "随机"),
    P_M_6_0("6_0", "03:00"),
    P_M_8_0("8_0", "5AM");

    private String code;
    private String desc;

    static final String[] MEAL_BEFORE = {P_M_1_2.getCode(), P_M_2_2.getCode(), P_M_3_2.getCode()};
    static final String[] MEAL_AFTER = {P_M_1_1.getCode(), P_M_2_1.getCode(), P_M_3_1.getCode()};

    public static boolean mealBefore(String code) {
        return Arrays.asList(MEAL_BEFORE).contains(code);
    }

    public static boolean mealAfter(String code) {
        return Arrays.asList(MEAL_AFTER).contains(code);
    }

    public static PeriodMarkEnum getPeriodMark(Integer period, Integer mark) {
        if(period == null || mark == null){
            return null;
        }
        return getByCode( String.format("%s_%s", period, mark));
    }

    public static PeriodMarkEnum getByCode(String periodMark) {
        if(periodMark == null){
            return null;
        }
        for (PeriodMarkEnum en:PeriodMarkEnum.values()) {
            if(en.getCode().equals(periodMark)){
                return en;
            }
        }
        return null;
    }

    public static PeriodMarkEnum getByDesc(String desc) {
        if(desc == null){
            return null;
        }
        for (PeriodMarkEnum en:PeriodMarkEnum.values()) {
            if(en.getDesc().equals(desc)){
                return en;
            }
        }
        return null;
    }


    public  static Boolean mealBefore(Integer period, Integer mark){
        PeriodMarkEnum periodMark = getPeriodMark(period, mark);
        if (null == periodMark){
            return false;
        }

        return  mealBefore(periodMark.getCode());
    }

    public  static Boolean mealAfter(Integer period, Integer mark){
        PeriodMarkEnum periodMark = getPeriodMark(period, mark);
        if (null == periodMark){
            return false;
        }

        return  mealAfter(periodMark.getCode());
    }
}
