package com.hgwebservice.util;

import cn.hutool.core.util.StrUtil;
import com.hgwebservice.entity.hisview.DispatchData;
import com.hgwebservice.entity.hisview.OperatorData;
import com.hgwebservice.entity.hisview.PatientData;
import com.hgwebservice.entity.server.MeasureData;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;

@Service
public class WebServiceUtil {
    private static final Logger log = LoggerFactory.getLogger(WebServiceUtil.class);
    private static final SimpleDateFormat SDF1_DATE_SHORT = new SimpleDateFormat("yyyy-MM-dd");
    private static final SimpleDateFormat SDF = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    public static final String END_POINT_URL = "http://192.168.8.225:8693/Select-Service?wsdl";
    public static final String END_POINT_URL_RESULT = "http://192.168.8.225:8693/Common-Service?wsdl";

    public WebServiceUtil() {
    }

    public static void main(String[] args) {
    }

    public static List<PatientData> getPatientDataByDeptCode(String deptCode) {
        List<PatientData> allPatientDataList = new ArrayList();

        try {
            String msgHeaderQuest = buildmsgHeaderXml("GetPatientHospitalInfo");
            String msgBodyQuest = patientBuildmsgBodyXml(deptCode);
            String[] inputNames = new String[]{"msgHeader", "msgBody"};
            String[] inputValues = new String[]{msgHeaderQuest, msgBodyQuest};
            Document document = SoapUtil.GeneratorWebserviceBySoap("soap12", END_POINT_URL, "http://www.zysoft.com/", "CallInterface", "http://www.zysoft.com/CallInterface", inputNames, inputValues, "zys:payload");
            if (document != null) {
                Element element = document.getDocumentElement();
                NodeList nodeList = element.getElementsByTagName("returnContent");
                System.out.println(nodeList.getLength());

                for(int j = 0; j < nodeList.getLength(); ++j) {
                    Element node = (Element)nodeList.item(j);
                    PatientData patientData = new PatientData();

                    try {
                        patientData.setPatientNo(getChildElementText(node, "visitNo"));
                        patientData.setHospitalNo(getChildElementText(node, "visitNo"));
                        patientData.setWristbandNo(getChildElementText(node, "patientId"));
                        patientData.setName(getChildElementText(node, "patientName"));
                        patientData.setGender(getChildElementText(node, "patientSex"));
                        patientData.setDeptCode(getChildElementText(node, "deptCode"));
                        patientData.setDeptName(getChildElementText(node, "deptName"));
                        patientData.setWardCode(getChildElementText(node, "wardCode"));
                        patientData.setWardName(getChildElementText(node, "wardName"));
                        String hisBedNo = getChildElementText(node, "bedNo");
                        String localBedNo = null;
                        if (StrUtil.isNotEmpty(hisBedNo)){
                            if ("233".equals(deptCode)) {
                                localBedNo = "内一" + hisBedNo;
                            } else if ("234".equals(deptCode)) {
                                localBedNo = "心脑血管" + hisBedNo;
                            } else if ("107".equals(deptCode)) {
                                localBedNo = "骨伤" + hisBedNo;
                            } else if ("236".equals(deptCode)) {
                                localBedNo = "外科" + hisBedNo;
                            } else if ("237".equals(deptCode)) {
                                localBedNo = "妇产" + hisBedNo;
                            } else if ("263".equals(deptCode)) {
                                localBedNo = "康复" + hisBedNo;
                            } else if ("123".equals(deptCode)) {
                                localBedNo = "肾内" + hisBedNo;
                            } else if ("400".equals(deptCode)) {
                                localBedNo = "手外" + hisBedNo;
                            } else if ("21".equals(deptCode)) {
                                localBedNo = "儿科" + hisBedNo;
                            } else if ("293".equals(deptCode)) {
                                localBedNo = "重症" + hisBedNo;
                            } else if ("26".equals(deptCode)) {
                                localBedNo = "肛肠" + hisBedNo;
                            } else if ("145".equals(deptCode)) {
                                localBedNo = "呼内" + hisBedNo;
                            } else if ("131".equals(deptCode)) {
                                localBedNo = "中医科" + hisBedNo;
                            } else {
                                localBedNo = hisBedNo;
                            }
                        }

                        patientData.setBedNo(localBedNo);
                        String birthday = getChildElementText(node, "patientBirthdate");
                        Date date = new Timestamp(SDF1_DATE_SHORT.parse(birthday.substring(0, 4) + "-" + birthday.substring(5, 7) + "-" + birthday.substring(8, 10)).getTime());
                        patientData.setBirthday(SDF.format(date));
                        patientData.setIdentifyNo(getChildElementText(node, "identityNo"));
                        String hospitalizedDate = getChildElementText(node, "inDate");
                        date = new Timestamp(SDF1_DATE_SHORT.parse(hospitalizedDate.substring(0, 4) + "-" + hospitalizedDate.substring(5, 7) + "-" + hospitalizedDate.substring(8, 10)).getTime());
                        patientData.setHospitalDate(SDF.format(date));
                        allPatientDataList.add(patientData);
                    } catch (Exception var17) {
                        log.error("Lack patient(" + getChildElementText(node, "patientno") + ") information");
                    }
                }
            }
            log.info(deptCode + "获取住院患者数量" + allPatientDataList.size());
            return allPatientDataList;
        } catch (Exception var18) {
            log.error("Get PatientDataByWardCode Fail !!! ", var18);
            return null;
        }
    }

    public static List<OperatorData> getOperatorData() {
        List<OperatorData> operatorDataList = new ArrayList();
        try {
            String msgHeaderQuest = buildmsgHeaderXml("GetStaffDict");
            String msgBodyQuest = operatorBuildmsgBodyXml();
            String[] inputNames = new String[]{"msgHeader", "msgBody"};
            String[] inputValues = new String[]{msgHeaderQuest, msgBodyQuest};
            Document document = SoapUtil.GeneratorWebserviceBySoap("soap12", END_POINT_URL, "http://www.zysoft.com/", "CallInterface", "http://www.zysoft.com/CallInterface", inputNames, inputValues, "zys:payload");
            if (document != null) {
                Element element = document.getDocumentElement();
                NodeList nodeList1 = element.getElementsByTagName("returnContent");
                for(int j = 0; j < nodeList1.getLength(); ++j) {
                    Element node = (Element)nodeList1.item(j);
                    OperatorData operatorDataTemp = new OperatorData();
                    String operatorNo = getChildElementText(node, "workCode");
                    String accName = getChildElementText(node, "staffName");
                    String deptCode = getChildElementText(node, "deptCode");
                    String deptName = getChildElementText(node, "deptName");
                    String wardCode = getChildElementText(node, "wardCode");
                    String wardName = getChildElementText(node, "wardName");
                    operatorDataTemp.setAcc(operatorNo);
                    operatorDataTemp.setAccName(accName);
                    operatorDataTemp.setIsEffective("0");
                    operatorDataTemp.setDeptCode(deptCode);
                    operatorDataTemp.setDeptName(deptName);
                    operatorDataTemp.setWardCode(wardCode);
                    operatorDataTemp.setWardName(wardName);
                    operatorDataList.add(operatorDataTemp);
                }
            }

            log.info("获取操作员" + operatorDataList.size());
            return operatorDataList;
        } catch (Exception var14) {
            log.error("Get AllOperatorData Fail !!! ", var14);
            return operatorDataList;
        }
    }

    public static List<DispatchData> getDispatchDataByDeptCode(String visitNo,String deptCode) {
        List<DispatchData> dispatcList = new ArrayList();

        try {
            String msgHeaderQuest = buildmsgHeaderXml("GetToPerformPrescribeRecord");
            String msgBodyQuest = dispatchBuildmsgBodyXml(visitNo);
            String[] inputNames = new String[]{"msgHeader", "msgBody"};
            String[] inputValues = new String[]{msgHeaderQuest, msgBodyQuest};
            Document document = SoapUtil.GeneratorWebserviceBySoap("soap12", END_POINT_URL, "http://www.zysoft.com/", "CallInterface", "http://www.zysoft.com/CallInterface", inputNames, inputValues, "zys:payload");
            if (document != null) {
                Element element = document.getDocumentElement();
                NodeList nodeList1 = element.getElementsByTagName("returnContent");
                System.out.println(nodeList1.getLength());

                for(int j = 0; j < nodeList1.getLength(); ++j) {
                    Element node = (Element)nodeList1.item(j);
                    DispatchData dispatchData = new DispatchData();
                    String patientNo = getChildElementText(node, "visitNo");
                    String dispatchNo = getChildElementText(node, "prescrobeNo");
                    String type = getChildElementText(node, "prescrobeType");
                    String message = getChildElementText(node, "prescrobeMessage");
                    String createDate = getChildElementText(node, "applyTime");
                    String establishDate = getChildElementText(node, "prescribeStartTime");
                    String period = getChildElementText(node, "measureTimePoint");
                    String frequency = getChildElementText(node, "performFreq");
                    dispatchData.setPatientNo(patientNo);
                    dispatchData.setDispatchNo(dispatchNo);
                    dispatchData.setFrequency(frequency);
                    dispatchData.setMessage(message);
                    dispatchData.setFrequency(period);
                    dispatchData.setDeptCode(deptCode);
                    dispatchData.setType(type);
                    if (StrUtil.isNotEmpty(period)){
                        dispatcList.add(dispatchData);
                    }
                }
            }
            if (dispatcList.size()>0){
                log.info(visitNo+"获取有效医嘱" + dispatcList.size());
            }
            return dispatcList;
        } catch (Exception var20) {
            log.error("Get DispatchData Fail !!! ", var20);
            return null;
        }
    }

    public static Boolean insertMeasureResult(MeasureData measureData) {
        Boolean bool = false;
        String lt = "<";
        String gt = ">";
        String response = "";

        try {
            String period = String.valueOf(measureData.getPeriodCode());
            if (period == null || period.equals("null")) {
                period = "随机";
                log.info("NO SELECT PEIOD  DEFAULT STAT ! ! !");
            }

            String analylsisNode = null;
                if ("早餐前".equals(period)) {
                    analylsisNode = "01";
                } else if ("早餐后2h".equals(period)) {
                    analylsisNode = "02";
                } else if ("午餐前".equals(period)) {
                    analylsisNode = "03";
                } else if ("午餐后2h".equals(period)) {
                    analylsisNode = "04";
                } else if ("晚餐前".equals(period)) {
                    analylsisNode = "05";
                } else if ("晚餐后2h".equals(period)) {
                    analylsisNode = "06";
                } else if ("睡前".equals(period)) {
                    analylsisNode = "07";
                } else if ("00:00".equals(period)) {
                    analylsisNode = "08";
                } else if ("03:00".equals(period)) {
                    analylsisNode = "09";
                }else {
                    analylsisNode = "00";
                }

            String msgHeaderQuest = buildmsgHeaderXml("SendBloodGlucoseRecord");
            StringBuilder sb = new StringBuilder();
            sb.append("<![CDATA[<root" + gt);
            sb.append(lt + "recordId" + gt);
            sb.append(measureData.getTestID());
            sb.append(lt + "/recordId" + gt);
            sb.append(lt + "patientId" + gt);
            sb.append(measureData.getMeterSn());
            sb.append(lt + "/patientId" + gt);
            sb.append(lt + "visitNo" + gt);
            sb.append(measureData.getPatientNO());
            sb.append(lt + "/visitNo" + gt);
            sb.append(lt + "visitType" + gt);
            sb.append("2");
            sb.append(lt + "/visitType" + gt);
            sb.append(lt + "patientName" + gt);
            sb.append(measureData.getName());
            sb.append(lt + "/patientName" + gt);
            sb.append(lt + "bedNo" + gt);
            sb.append(measureData.getStripLot());
            sb.append(lt + "/bedNo" + gt);
            sb.append(lt + "visitDeptCode" + gt);
            sb.append(measureData.getDispatchNO());
            sb.append(lt + "/visitDeptCode" + gt);
            sb.append(lt + "bloodGlucoseValue" + gt);
            sb.append(measureData.getMeasureValue());
            sb.append(lt + "/bloodGlucoseValue" + gt);
            sb.append(lt + "measureDate" + gt);
            sb.append(measureData.getMeasureDate().substring(0, 10));
            sb.append(lt + "/measureDate" + gt);
            sb.append(lt + "measureTimePoint" + gt);
            sb.append(measureData.getMeasureDate().substring(0, 16));
            sb.append(lt + "/measureTimePoint" + gt);
            sb.append(lt + "analylsisNode" + gt);
            sb.append(analylsisNode);
            sb.append(lt + "/analylsisNode" + gt);
            sb.append(lt + "operateType" + gt);
            sb.append("1");
            sb.append(lt + "/operateType" + gt);
            sb.append(lt + "createOperatorId" + gt);
            sb.append(lt + "/createOperatorId" + gt);
            sb.append(lt + "createOperator" + gt);
            sb.append(measureData.getAcc());
            sb.append(lt + "/createOperator" + gt);
            sb.append(lt + "createTime" + gt);
            sb.append(SDF.format(new Date()));
            sb.append(lt + "/createTime" + gt);
            sb.append(lt + "measureMachineNo" + gt);
            sb.append(lt + "/measureMachineNo" + gt);
            sb.append(lt + "measureMmaterialsNo" + gt);
            sb.append(lt + "/measureMmaterialsNo" + gt);
            sb.append(lt + "prescrobeNo" + gt);
            sb.append(lt + "/prescrobeNo" + gt);
            sb.append(lt + "/root>]]>");
            String msgBodyQuest = sb.toString();
//            log.info("回传字符串:" + msgBodyQuest);
            String[] inputNames = new String[]{"msgHeader", "msgBody"};
            String[] inputValues = new String[]{msgHeaderQuest, msgBodyQuest};
            log.info("回显his参数",inputValues);
            response = SoapUtil.GeneratorWebserviceBySoapResultUpload("soap12", END_POINT_URL_RESULT, "http://www.zysoft.com/", "CallInterface", "http://www.zysoft.com/CallInterface", inputNames, inputValues, "zys:payload");
        } catch (Exception var12) {
            log.error("doReplyResult fail ", var12);
            return false;
        }

        if (response.contains("OK")) {
            bool = true;
        } else {
            bool = false;
        }

        return bool;
    }

    public static String getChildElementText(Element node, String tagName) {
        Element elt = getChildElement(node, tagName);
        return elt != null ? getText(elt) : "";
    }

    public static Element getChildElement(Element node, String tagName) {
        NodeList list = node.getElementsByTagName(tagName);
        return list.getLength() > 0 ? (Element)list.item(0) : null;
    }

    public static String getText(Node node) {
        String value = null;

        for(Node child = node.getFirstChild(); child != null; child = child.getNextSibling()) {
            short type = child.getNodeType();
            if (type == 3 || type == 4) {
                value = child.getNodeValue();
                break;
            }
        }

        return get(value);
    }

    public static String get(String s) {
        return s == null ? "" : s.trim();
    }

    private static String buildmsgHeaderXml(String url) {
        String lt = "<";
        String gt = ">";
        StringBuilder sb = new StringBuilder();
        sb.append("<![CDATA[<root" + gt);
        sb.append(lt + "serverName" + gt);
        sb.append(url);
        sb.append(lt + "/serverName" + gt);
        sb.append(lt + "format" + gt);
        sb.append("xml");
        sb.append(lt + "/format" + gt);
        sb.append(lt + "certificate" + gt);
        sb.append("ArzMFVA4bgM4yiZs35q24w==");
        sb.append(lt + "/certificate" + gt);
        String uuid = UUID.randomUUID().toString().replace("-", "").toLowerCase();
        sb.append(lt + "msgNo" + gt);
        sb.append(uuid);
        sb.append(lt + "/msgNo" + gt);
        String date = SDF.format(new Date());
        sb.append(lt + "sendTime" + gt);
        sb.append(date);
        sb.append(lt + "/sendTime" + gt);
        sb.append(lt + "/root>]]>");
//        log.info("RequestXml:" + sb.toString());
//        log.info("");
        String[] sa = new String[]{sb.toString()};
        return sa[0];
    }

    private static String patientBuildmsgBodyXml(String deptCode) {
        String lt = "<";
        String gt = ">";
        StringBuilder sb = new StringBuilder();
        sb.append("<![CDATA[<root" + gt);
        sb.append(lt + "deptCode" + gt);
        sb.append(deptCode);
        sb.append(lt + "/deptCode" + gt);
        sb.append(lt + "wardCode" + gt);
        sb.append(lt + "/wardCode" + gt);
        sb.append(lt + "visitStatus" + gt);
        sb.append("1");
        sb.append(lt + "/visitStatus" + gt);
        sb.append(lt + "/root>]]>");
//        log.info("RequestXml:" + sb.toString());
//        log.info("");
        String[] sa = new String[]{sb.toString()};
        return sa[0];
    }

    private static String operatorBuildmsgBodyXml() {
        String lt = "<";
        String gt = ">";
        StringBuilder sb = new StringBuilder();
        sb.append("<![CDATA[<root" + gt);
        sb.append(lt + "orgCode" + gt);
        sb.append(lt + "/orgCode" + gt);
        sb.append(lt + "deptCode" + gt);
        sb.append(lt + "/deptCode" + gt);
        sb.append(lt + "staffName" + gt);
        sb.append(lt + "/staffName" + gt);
        sb.append(lt + "/root>]]>");
//        log.info("RequestXml:" + sb.toString());
//        log.info("");
        String[] sa = new String[]{sb.toString()};
        return sa[0];
    }

    private static String dispatchBuildmsgBodyXml(String patientNo) {
        String lt = "<";
        String gt = ">";
        StringBuilder sb = new StringBuilder();
        sb.append("<![CDATA[<root" + gt);
        sb.append(lt + "visitNo" + gt);
        sb.append(patientNo);
        sb.append(lt + "/visitNo" + gt);
        sb.append(lt + "/root>]]>");
//        log.info("RequestXml:" + sb.toString());
//        log.info("");
        String[] sa = new String[]{sb.toString()};
        return sa[0];
    }
}
